@@ -1,3 +1,3 @@
 write.tab <- function(data, filename, quote=FALSE, row.names=FALSE, ...) {
-    write.table(data, filename, quote, row.names, ...)
+    write.table(x=data, file=filename, quote=quote, row.names=FALSE, ...)
 }
