@@ -1,3 +1,3 @@
 write.tab <- function(data, filename, sep="\t", quote=FALSE, row.names=FALSE, ...) {
-    write.table(data, filename, sep, quote, row.names, ...)
+    write.table(x=data, file=filename, sep, quote, row.names, ...)
 }
